@@ -32,11 +32,11 @@ Re class in L<SPVM> has methods for more Perlish regular expression.
 
 =head2 m
 
-C<static method m : L<Regex::Match|SPVM::Regex::Match> ($string_value : string|L<StringBuffer|SPVM::StringBuffer>, $pattern_and_flags : string|string[], $offset_ref : int* = undef, $length : int = -1);>
+C<static method m : L<Regex::Match|SPVM::Regex::Match> ($string : string, $pattern_and_flags : string|string[], $offset_ref : int* = undef, $length : int = -1);>
 
 Calls L<Regex#new|SPVM::Regex/"new"> method given $pattern_and_flags. $pattern_and_flags is a pattern string or a string array that contains a pattern and flags.
 
-And the returned L<Regex|SPVM::Regex> object calls L<Regex#match|SPVM::Regex/"match"> method given $string_value, $offset_ref, $offset_ref, $length, and returns its return value.
+And the returned L<Regex|SPVM::Regex> object calls L<Regex#match|SPVM::Regex/"match"> method given $string, $offset_ref, $offset_ref, $length, and returns its return value.
 
 The L<Regex|SPVM::Regex> object is cached.
 
@@ -46,11 +46,11 @@ Exceptions thrown by L<Regex#new|SPVM::Regex/"new"> method and L<Regex#match|SPV
 
 =head2 s
 
-C<static method s : L<Regex::ReplaceInfo|SPVM::Regex::ReplaceInfo> ($string_ref_value : mutable string|string[]|L<StringBuffer|SPVM::StringBuffer>, $pattern_and_flags : string|string[], $replace : string|L<Regex::Replacer|SPVM::Regex::Replacer>, $offset_ref : int* = undef, $length : int = -1);>
+C<static method s : L<Regex::ReplaceInfo|SPVM::Regex::ReplaceInfo> ($string : mutable string, $pattern_and_flags : string|string[], $replace : string|L<Regex::Replacer|SPVM::Regex::Replacer>, $offset_ref : int* = undef, $length : int = -1);>
 
 Calls L<Regex#new|SPVM::Regex/"new"> method given $pattern_and_flags. $pattern_and_flags is a pattern string or a string array that contains a pattern and flags.
 
-And the returned L<Regex|SPVM::Regex> object calls L<Regex#replace|SPVM::Regex/"replace"> method given $string_ref_value, $offset_ref, $offset_ref, $length, and returns its return value.
+And the returned L<Regex|SPVM::Regex> object calls L<Regex#replace|SPVM::Regex/"replace"> method given $string, $offset_ref, $offset_ref, $length, and returns its return value.
 
 The flags in $pattern_and_flags can contains C<"g"> to L<Regex#replace_g|SPVM::Regex/"replace_g"> method instead of L<Regex#replace|SPVM::Regex/"replace"> method.
 
